Learn R Programming

ieegio (version 0.0.9)

as_nifti_header: Internal method to extract header information from a 'NIfTI' file

Description

Internal method to extract header information from a 'NIfTI' file

Usage

as_nifti_header(x)

Value

A list containing the file header information

Arguments

x

file path or an R object